pub enum AttestationError {
InvalidRequest {
message: String,
},
Fetch(VeniceClientError),
MalformedResponse {
message: String,
},
MissingField {
field: &'static str,
},
PolicyViolation {
code: AttestationFailureCode,
message: String,
},
ExternalVerifierUnavailable {
verifier: &'static str,
message: String,
},
}Expand description
Errors returned while fetching or validating attestation evidence.
Variants
Implementations
Sourceimpl AttestationError
impl AttestationError
Sourcepub fn api_error_type(&self) -> &'static str
pub fn api_error_type(&self) -> &'static str
Returns the OpenAI-compatible error type exposed for this attestation error.
Sourcepub fn api_error_code(&self) -> &'static str
pub fn api_error_code(&self) -> &'static str
Returns the proxy error code exposed for this attestation error.
Returns whether the error indicates a required external attestation verifier is unavailable.