pub struct SessionHeadersConfig {
pub incoming_session_id: String,
}Expand description
Header names used to resolve stable agent session identifiers.
Fields
incoming_session_id: StringTrait Implementations
Sourceimpl Clone for SessionHeadersConfig
impl Clone for SessionHeadersConfig
Sourcefn clone(&self) -> SessionHeadersConfig
fn clone(&self) -> SessionHeadersConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for SessionHeadersConfig
impl Debug for SessionHeadersConfig
Sourceimpl Default for SessionHeadersConfig
impl Default for SessionHeadersConfig
Sourceimpl<'de> Deserialize<'de> for SessionHeadersConfigwhere
SessionHeadersConfig: Default,
impl<'de> Deserialize<'de> for SessionHeadersConfigwhere
SessionHeadersConfig: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl Eq for SessionHeadersConfig
Sourceimpl PartialEq for SessionHeadersConfig
impl PartialEq for SessionHeadersConfig
Sourcefn eq(&self, other: &SessionHeadersConfig) -> bool
fn eq(&self, other: &SessionHeadersConfig) -> bool
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SessionHeadersConfig