Module e2ee

Module e2ee 

Venice E2EE encryption/decryption codec.

Implements the Venice E2EE field codec:

ephemeral_public_key[65 bytes] || nonce[12 bytes] || ciphertext_and_gcm_tag

The packed bytes are serialized as lowercase hex strings in request message content fields and in encrypted Venice streaming response delta.content fields.

Structs

ContentEncryptionKey
An AES-256-GCM content-encryption key derived from ECDH + HKDF-SHA256.
E2eeCodec
E2EE codec configured with the HKDF info string and fail-closed response policy.
EncryptedPayload
Venice encrypted payload serialized as a lowercase hex string.
Nonce
AES-GCM nonce used by the Venice field codec.

Enums

E2eeCodecError
Errors returned by E2EE request encryption and response decryption.

Constants

AES_256_KEY_LEN
AES_GCM_TAG_LEN
EPHEMERAL_PUBLIC_KEY_LEN
MIN_PACKED_PAYLOAD_LEN
NONCE_LEN
PACKED_PREFIX_LEN