pub struct AppState { /* private fields */ }Expand description
Shared HTTP application state used by route handlers.
Implementations
Sourceimpl AppState
impl AppState
Sourcepub fn new(config: ProxyConfig) -> Result<Self, VeniceClientError>
pub fn new(config: ProxyConfig) -> Result<Self, VeniceClientError>
Builds application state from configuration and a Venice client created from that config.
Sourcepub fn from_parts(config: ProxyConfig, venice_client: VeniceClient) -> Self
pub fn from_parts(config: ProxyConfig, venice_client: VeniceClient) -> Self
Builds application state from configuration and an already-created Venice client.
Sourcepub fn config(&self) -> &ProxyConfig
pub fn config(&self) -> &ProxyConfig
Returns the proxy configuration shared by handlers.
Sourcepub fn venice_client(&self) -> &VeniceClient
pub fn venice_client(&self) -> &VeniceClient
Returns the Venice upstream client shared by handlers.
Sourcepub fn proxy_instance_key(&self) -> Option<&ProxyInstanceKey>
pub fn proxy_instance_key(&self) -> Option<&ProxyInstanceKey>
Returns the startup proxy instance key when key generation is enabled.
Sourcepub fn session_manager(&self) -> &SessionManager
pub fn session_manager(&self) -> &SessionManager
Returns the in-memory session manager shared by handlers.
Sourcepub fn attestation_verifier(&self) -> &AttestationVerifier
pub fn attestation_verifier(&self) -> &AttestationVerifier
Returns the attestation verifier shared by handlers.