pub struct ProxyMetadataHeaders {
pub e2ee: Option<String>,
pub attestation_mode: Option<String>,
pub attested_model: Option<String>,
pub tee_provider: Option<String>,
pub tdx_verified: Option<bool>,
pub tdx_debug: Option<bool>,
pub nvidia_verified: Option<String>,
pub key_binding: Option<bool>,
pub session_id: Option<String>,
pub session_scope: Option<String>,
pub tool_mode: Option<String>,
pub tool_retries: Option<u32>,
}Expand description
Safe proxy metadata headers.
Fields are optional so handlers never claim E2EE, attestation, key-binding, or session verification that has not happened yet.
Fields
e2ee: Option<String>attestation_mode: Option<String>attested_model: Option<String>tee_provider: Option<String>tdx_verified: Option<bool>tdx_debug: Option<bool>nvidia_verified: Option<String>key_binding: Option<bool>session_id: Option<String>session_scope: Option<String>tool_mode: Option<String>tool_retries: Option<u32>Implementations
Sourceimpl ProxyMetadataHeaders
impl ProxyMetadataHeaders
Sourcepub fn from_config(config: &ProxyConfig) -> Self
pub fn from_config(config: &ProxyConfig) -> Self
Creates safe non-assertive metadata from config before a route has verification/session state.
Sourcepub fn for_verified_chat(config: &ProxyConfig, session: &SessionContext) -> Self
pub fn for_verified_chat(config: &ProxyConfig, session: &SessionContext) -> Self
Creates metadata headers for a chat response after session attestation succeeds.