Module keys

Module keys 

Startup proxy-instance key management.

The proxy generates one secp256k1 keypair per process when configured to do so. E2EE code uses the private key to decrypt Venice response chunks and sends the uncompressed public key hex in Venice E2EE request headers.

Structs

ProxyInstanceKey
Per-process secp256k1 keypair used by this proxy instance.