pub enum ChatConstructionError {
E2ee(E2eeCodecError),
}Expand description
Errors returned while constructing the encrypted Venice chat request.
Variants
E2ee(E2eeCodecError)
Implementations
Sourceimpl ChatConstructionError
impl ChatConstructionError
Sourcepub fn api_error_code(&self) -> &'static str
pub fn api_error_code(&self) -> &'static str
Returns the proxy error code exposed for this construction error.