Venice E2EE encryption/decryption codec.
Implements the Venice E2EE field codec:
ephemeral_public_key[65 bytes] || nonce[12 bytes] || ciphertext_and_gcm_tagThe packed bytes are serialized as lowercase hex strings in request message
content fields and in encrypted Venice streaming response delta.content
fields.
Structs
- Content
Encryption Key - An AES-256-GCM content-encryption key derived from ECDH + HKDF-SHA256.
- E2ee
Codec - E2EE codec configured with the HKDF info string and fail-closed response policy.
- Encrypted
Payload - Venice encrypted payload serialized as a lowercase hex string.
- Nonce
- AES-GCM nonce used by the Venice field codec.
Enums
- E2ee
Codec Error - Errors returned by E2EE request encryption and response decryption.