pub struct SessionManager { /* private fields */ }Expand description
In-memory session manager that resolves request identifiers and tracks session expiry.
Implementations
Sourceimpl SessionManager
impl SessionManager
Sourcepub fn new(config: SessionConfig) -> Self
pub fn new(config: SessionConfig) -> Self
Creates an empty session manager using the supplied session policy.
Sourcepub fn get_or_create(
&self,
request: SessionRequest<'_>,
) -> Result<SessionResolution, SessionError>
pub fn get_or_create( &self, request: SessionRequest<'_>, ) -> Result<SessionResolution, SessionError>
Resolves, creates, or refreshes the session for a request using the current wall-clock time.
Sourcepub fn get_or_create_at(
&self,
request: SessionRequest<'_>,
now: SystemTime,
) -> Result<SessionResolution, SessionError>
pub fn get_or_create_at( &self, request: SessionRequest<'_>, now: SystemTime, ) -> Result<SessionResolution, SessionError>
Testable variant of Self::get_or_create with an injected clock.
Sourcepub fn set_attested_model_state(
&self,
session_key: &str,
state: AttestedModelState,
) -> Result<SessionContext, SessionError>
pub fn set_attested_model_state( &self, session_key: &str, state: AttestedModelState, ) -> Result<SessionContext, SessionError>
Stores verified attestation/model-key state in an existing, unexpired session.
Sourcepub fn set_attested_model_state_at(
&self,
session_key: &str,
state: AttestedModelState,
now: SystemTime,
) -> Result<SessionContext, SessionError>
pub fn set_attested_model_state_at( &self, session_key: &str, state: AttestedModelState, now: SystemTime, ) -> Result<SessionContext, SessionError>
Testable variant of Self::set_attested_model_state with an injected clock.
Sourcepub fn cleanup_expired(&self) -> usize
pub fn cleanup_expired(&self) -> usize
Removes expired sessions and returns the number removed.
Sourcepub fn cleanup_expired_at(&self, now: SystemTime) -> usize
pub fn cleanup_expired_at(&self, now: SystemTime) -> usize
Testable cleanup variant with an injected clock.